@@ -28,7 +28,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.33';
+our $VERSION = '2.34';
 
 =head1 SYNOPSIS
 
@@ -829,6 +829,10 @@ sub process_batch{
     #Need to get absolute path going on...
 #    $self->cmdfile($self->jobname."_batch".$self->batch_counter.".in");
 
+    if($self->use_gnuparallel){
+        $command = "cd ".getcwd()."\n";
+        $command .= "cat ".$self->cmdfile." | paralellparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
+    }
     if($self->use_threads){
         $command = "cd ".getcwd()."\n"; #Go back to the working directory just to be safe
         $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
@@ -838,6 +842,8 @@ sub process_batch{
         $command .= "mcerunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
     }
 
+    $DB::single=2;
+
     $self->template->process($self->template_file, 
         { JOBNAME => $self->jobname."_".$self->batch_counter, 
             USER => $self->user, 
@@ -847,7 +853,6 @@ sub process_batch{
             AFTEROK => $ok, 
             OUT => $self->logdir."/".$self->jobname."_".$self->batch_counter.".log",
             MODULE => $self->module,
-#            COMMAND => "perl /data/apps/software/slurm_scripts/paralellnoderunner.pl --procs 3 --infile ".$self->cmdfile." --outdir ".$self->outdir },
             COMMAND => $command },
         $self->slurmfile
     ) || die $self->template->error;
